==> filmeverwaltung-0.0.2.tar.bz2: filmeverwaltung/korrektur.php <==
<?php
// filmeverwaltung - korrektur.php      Copyright (C) 2009 Oliver Burger
// oliver [at] mandrivauser [dot] de    http://www.mandrivauser.de
//
// This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//


	// beginnendes HTML-Gedöhns
	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
	<HTML>
	<Head>
	<Title>
		CD-Register
	</Title>
	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">
	<link rel=stylesheet type=\"text/css\" href=\"./style_eingabe.css\">
	</Head>
	<Body bgcolor=\"#f0f0ff\" text=\"#000044\">";
	echo "<h1>Filmesammlungs-Verwaltung</h1>
		<p>Hier k&ouml;nnen Sie die Eintr&auml;ge Ihrer Sammlung
		korrigieren</p><br />";
	echo "&nbsp;|&nbsp; <a href=\"./index.php\">&Uuml;bersicht</a>
		&nbsp;|&nbsp; <a href=\"./einlesen.php\">Einlesen neuer 
		Filme</a> &nbsp;|&nbsp;
	<font color=\"#cc00cc\" size=\"+1\"><b>Korrektur von
		Eintr&auml;gen</b></font> &nbsp;|&nbsp<br /><br />";

	// Deklaration der benoetigten Arrays
	$raw_register = array();
	$register = array();

	// Einlesen der Datei
	$data_file = fopen("data/cd-register","r");
	while(!feof($data_file))
	{
		$zeile = fgets($data_file,1024);
		$raw_register[] = $zeile;
	}
	fclose($data_file);

	// Erstellen des Haupt-Arrays
	for($i = 0; $i < count($raw_register)-1; $i++)
	{
		$register[$i] = explode("|",$raw_register[$i]);
	}

	// Abfrage der zu korrigierenden Filmnummer
	#$filmnummer = 0;
	echo "<form action=\"./korrektur.php\" method=\"post\">
	<table align=\"center\"><tr><td>Laufende Nummer der zu korrigierenden Datei:</td>
	<td><input type=\"Text\" name=\"filmnummer\" size=\"4\"></td></table>
	<center><input type=\"Submit\" value=\"Absenden\"></center>
	</form>";
	$filmnummer = $_POST["filmnummer"];

	// Eingabe der Daten
	if($filmnummer != "")
	{
		echo "<form action=\"./korrektur.php\" method=\"post\">
		<table width=\"98%\" align=\"center\">
		<tr><th align=\"center\">Laufende Nummer</th>
		<th align=\"center\">Film</th>
		<th align=\"center\">Genre</th>
		<th align=\"center\">Schauspieler</th>
		<th align=\"center\">CD-Case</th>
		<th align=\"center\">Medien-Nummer</th></tr>
		<tr><td align=\"center\"><input type=\"Text\" name=\"filmnummer\" value=\"".$filmnummer."\" size=\"4\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"filmname\" value=\"".$register[$filmnummer][0]."\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"genre\" value=\"".$register[$filmnummer][1]."\" accept-charset=\"ISO-8859-1\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"schauspieler\" value=\"".$register[$filmnummer][2]."\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"cd_case\" value=\"".$register[$filmnummer][3]."\" size=\"6\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"medien_nummer\" value=\"".$register[$filmnummer][4]."\" size=\"10\"></td></tr>
		<table><br />
		<center><input type=\"Submit\" value=\"Absenden\"></center>
		</form><br />";
	
		// Auslesen der Einnahmen
		$filmnummer = $_POST["filmnummer"];
		$filmname = $_POST["filmname"];
		$genre = $_POST["genre"];
		$schauspieler = $_POST["schauspieler"];
		$cd_case = $_POST["cd_case"];
		$medien_nummer = $_POST["medien_nummer"];
	}

	if($filmnummer >=0 AND $filmnummer < count($register) AND $filmname != "")
	{
		$eingabe = array();
		$eingabe[0]=$filmname;
		$eingabe[1]=$genre;
		$eingabe[2]=$schauspieler;
		$eingabe[3]=$cd_case;
		$eingabe[4]=$medien_nummer."\n";
		// Konvertieren der Sonderzeichen
		for($i=0; $i<5; $i++)
		{
			$eingabe[$i]=htmlentities($eingabe[$i]);
		}
		$register[$filmnummer]=$eingabe;
	}
	else
	{
		if($filmnummer != "")
		{
			echo "<br /><br /><p>Die Dateinummer war falsch oder der
			Filmname wurde nicht angegeben</p><br /><br />";
		}
	}
		
	// Ausgabe der Tabelle
	echo "<table border=1>
		<tr><th>Nr.<th>Titel</th><th>Genre</th><th>Schauspieler</th>
		<th>CD-Case</th><th>Medien-Nummer</th></tr>";
	for($i=0;$i<count($register);$i++)
	{
		echo "<tr><td>".$i."</td><td>".$register[$i][0]."</td>
		<td>".$register[$i][1]."</td><td>".$register[$i][2]."</td>
		<td>".$register[$i][3]."</td><td>".$register[$i][4]."</td>
		</tr>";
	}
	echo "</table>";

	// Abspeichern der Daten
	if($filmnummer >=0 AND $filmnummer < count($register)
		AND $filmname != "")
	{
		for($i=0; $i<count($register); $i++)
		{
			$raw_register[$i] = implode("|",$register[$i]);
		}

		// Speichern der Daten in die Datei
		$data_file = fopen("data/cd-register","w+");
		rewind($data_file);
		for($i=0;$i<count($raw_register);$i++)
		{
			$zeile = $raw_register[$i];
			fputs($data_file,$zeile);
			#fputs($data_file,$raw_register);
		}
		fclose($data_file);
		echo "<br /><p>Die &Auml;nderungen wurden gespeichert.</p>
			<br />";
	}	

	$filmnummer="";

	// abschließendes HTML-Gedöhns...
	echo "<br /><a href=\"#top\">Nach oben</a>";

	echo "</Body>
	</HTML>";

?>

==> filmeverwaltung-0.0.2.1.tar.bz2: filmeverwaltung/korrektur.php <==
<?php
// This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//


	// beginnendes HTML-Gedöhns
	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
	<HTML>
	<Head>
	<Title>
		CD-Register
	</Title>
	<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">
	<link rel=stylesheet type=\"text/css\" href=\"./style_eingabe.css\">
	</Head>
	<Body bgcolor=\"#f0f0ff\" text=\"#000044\">";
	echo "<h1>Filmesammlungs-Verwaltung</h1>
		<p>Hier k&ouml;nnen Sie die Eintr&auml;ge Ihrer Sammlung
		korrigieren</p><br />";
	echo "&nbsp;|&nbsp; <a href=\"./index.php\">&Uuml;bersicht</a>
		&nbsp;|&nbsp; <a href=\"./einlesen.php\">Einlesen neuer 
		Filme</a> &nbsp;|&nbsp;
	<font color=\"#cc00cc\" size=\"+1\"><b>Korrektur von
		Eintr&auml;gen</b></font> &nbsp;|&nbsp<br /><br />";

	// Deklaration der benoetigten Arrays
	$raw_register = array();
	$register = array();

	// Einlesen der Datei
	$data_file = fopen("data/cd-register","r");
	while(!feof($data_file))
	{
		$zeile = fgets($data_file,1024);
		$raw_register[] = $zeile;
	}
	fclose($data_file);

	// Erstellen des Haupt-Arrays
	for($i = 0; $i < count($raw_register)-1; $i++)
	{
		$register[$i] = explode("|",$raw_register[$i]);
	}

	// Abfrage der zu korrigierenden Filmnummer
	#$filmnummer = 0;
	echo "<form action=\"./korrektur.php\" method=\"post\">
	<table align=\"center\"><tr><td>Laufende Nummer der zu korrigierenden Datei:</td>
	<td><input type=\"Text\" name=\"filmnummer\" size=\"4\"></td></table>
	<center><input type=\"Submit\" value=\"Absenden\"></center>
	</form>";
	$filmnummer = $_POST["filmnummer"];

	// Eingabe der Daten
	if($filmnummer != "")
	{
		echo "<form action=\"./korrektur.php\" method=\"post\">
		<table width=\"98%\" align=\"center\">
		<tr><th align=\"center\">Laufende Nummer</th>
		<th align=\"center\">Film</th>
		<th align=\"center\">Genre</th>
		<th align=\"center\">Schauspieler</th>
		<th align=\"center\">CD-Case</th>
		<th align=\"center\">Medien-Nummer</th></tr>
		<tr><td align=\"center\"><input type=\"Text\" name=\"filmnummer\" value=\"".$filmnummer."\" size=\"4\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"filmname\" value=\"".$register[$filmnummer][0]."\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"genre\" value=\"".$register[$filmnummer][1]."\" accept-charset=\"ISO-8859-1\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"schauspieler\" value=\"".$register[$filmnummer][2]."\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"cd_case\" value=\"".$register[$filmnummer][3]."\" size=\"6\"></td>
		<td align=\"center\"><input type=\"Text\" name=\"medien_nummer\" value=\"".$register[$filmnummer][4]."\" size=\"10\"></td></tr>
		<table><br />
		<center><input type=\"Submit\" value=\"Absenden\"></center>
		</form><br />";
	
		// Auslesen der Einnahmen
		$filmnummer = $_POST["filmnummer"];
		$filmname = $_POST["filmname"];
		$genre = $_POST["genre"];
		$schauspieler = $_POST["schauspieler"];
		$cd_case = $_POST["cd_case"];
		$medien_nummer = $_POST["medien_nummer"];
	}

	if($filmnummer >=0 AND $filmnummer < count($register) AND $filmname != "")
	{
		$eingabe = array();
		$eingabe[0]=$filmname;
		$eingabe[1]=$genre;
		$eingabe[2]=$schauspieler;
		$eingabe[3]=$cd_case;
		$eingabe[4]=$medien_nummer."\n";
		// Konvertieren der Sonderzeichen
		for($i=0; $i<5; $i++)
		{
			$eingabe[$i]=htmlentities($eingabe[$i]);
		}
		$register[$filmnummer]=$eingabe;
	}
	else
	{
		if($filmnummer != "")
		{
			echo "<br /><br /><p>Die Dateinummer war falsch oder der
			Filmname wurde nicht angegeben</p><br /><br />";
		}
	}
		
	// Ausgabe der Tabelle
	echo "<table border=1 width=\"98%\"><tr>
		<th width=\"3%\">Nr.</th>
		<th width=\"29%\">Titel</th>
		<th width=\"14%\">Genre</th>
		<th width=\"29%\">Schauspieler</th>
		<th width=\"10%\">CD-Case</th>
		<th width=\"14%\">Medien-Nummer</th></tr>";
	for($i=0;$i<count($register);$i++)
	{
		echo "<tr><td>".$i."</td><td>".$register[$i][0]."</td>
		<td>".$register[$i][1]."</td><td>".$register[$i][2]."</td>
		<td>".$register[$i][3]."</td><td>".$register[$i][4]."</td>
		</tr>";
	}
	echo "</table>";

	// Abspeichern der Daten
	if($filmnummer >=0 AND $filmnummer < count($register)
		AND $filmname != "")
	{
		for($i=0; $i<count($register); $i++)
		{
			$raw_register[$i] = implode("|",$register[$i]);
		}

		// Speichern der Daten in die Datei
		$data_file = fopen("data/cd-register","w+");
		rewind($data_file);
		for($i=0;$i<count($raw_register);$i++)
		{
			$zeile = $raw_register[$i];
			fputs($data_file,$zeile);
			#fputs($data_file,$raw_register);
		}
		fclose($data_file);
		echo "<br /><p>Die &Auml;nderungen wurden gespeichert.</p>
			<br />";
	}	

	$filmnummer="";

	// abschließendes HTML-Gedöhns...
	echo "<br /><a href=\"#top\">Nach oben</a>";

	echo "</Body>
	</HTML>";

?>
